@@ -10,7 +10,7 @@ make-debug	<g  with-input-from-port	=g  with-output-to-port	>g  with-error
 	B 	Cg  
 start-repl	DBC 	EBC 	Fg  debugS	Gg  pass	Hg  disabled	Ig  error	Jf  Unknown trap-handler strategy	Kg  with-default-trap-handler	Lg  %start-stack	Mg  report	Ng  memq	Og  throw	Pg  run-hook	Qg  before-error-hook	Rg  after-error-hook	Sg  force-output	Tg  
 procedure?	Uf  Unknown post-error strategy	Vg  	backtrace	Wg  print-frames	Xf  Unknown on-error strategy	Yg  make-syntax-transformer	ZY 	[Y 	\g  macro	]g  $sc-dispatch	^] 	_] 	`g  any	a`` 	bg  
-syntax-object	cg  top	dc 	eg  ribcage	fg  dummy	gg  form	hfg 	ig  m-ZfFEXjLRkk57ADkaMYTJEh-8763	jic 	kjd 	lf  l-ZfFEXjLRkk57ADkaMYTJEh-8768	mf  l-ZfFEXjLRkk57ADkaMYTJEh-8769	nlm 	oehkn 	pe 	qg  x	rq 	sj 	tf  l-ZfFEXjLRkk57ADkaMYTJEh-8765	ut 	versu 	wdopv 	xg  hygiene	yx 	zbwy 	{g  lambda	|b{wy 	}g  syntax-violation	~} 	}  f  -source expression failed to match any patternC 5     hx  r   ]4	
+syntax-object	cg  top	dc 	eg  ribcage	fg  dummy	gg  form	hfg 	ig  m-DX5KpJIvbsAwGr4oljmO8M-8234	jic 	kjd 	lf  l-DX5KpJIvbsAwGr4oljmO8M-8239	mf  l-DX5KpJIvbsAwGr4oljmO8M-8240	nlm 	oehkn 	pe 	qg  x	rq 	sj 	tf  l-DX5KpJIvbsAwGr4oljmO8M-8236	ut 	versu 	wdopv 	xg  hygiene	yx 	zbwy 	{g  lambda	|b{wy 	}g  syntax-violation	~} 	}  f  -source expression failed to match any patternC 5     hx  r   ]4	
  5 4# >  "  G   $%& h(      ]	
 4L 5$  L 
 "   LL6         g  port
